@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::StaticLog;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub register {
     my ($self, $app, $conf) = @_;
@@ -12,8 +12,7 @@ sub register {
         after_static => sub {
             my $c        = shift;
             my $log      = $c->app->log;
-            my $is_level = "is_$level";
-            return unless $log->$is_level;
+            return unless $log->is_level($level);
             my $path = $c->req->url->path;
             my $size = sprintf '%6s', $c->res->content->body_size;
             my $code = $c->res->code;
@@ -78,7 +77,7 @@ or
 
   $plugin->register($app, {level => $level}) # where $level =~ /debug|info|warn|error|fatal/
 
-Adds an appropriate after_static hook for loggin static file responses.
+Adds an appropriate after_static hook for logging static file responses.
 
 =head1 REPOSITORY
 
@@ -92,6 +91,6 @@ This program is free software, you can redistribute it and/or modify it under th
 
 =head1 SEE ALSO
 
-L<Mojolicious::Log>, L<Mojolicious::Static>, L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
+L<Mojo::Log>, L<Mojolicious::Static>, L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
 
 =cut
